import React from 'react';
import { Camera } from '@babylonjs/core/Cameras/camera.js';
import { EngineOptions } from '@babylonjs/core/Engines/thinEngine.js';
import { EventState } from '@babylonjs/core/Misc/observable.js';
import { Scene, SceneOptions } from '@babylonjs/core/scene.js';
import { Nullable } from '@babylonjs/core/types.js';
export * from './engine';
export * from './scene';
export declare type BabylonjsProps = {
    antialias?: boolean;
    engineOptions?: EngineOptions;
    adaptToDeviceRatio?: boolean;
    renderChildrenWhenReady?: boolean;
    sceneOptions?: SceneOptions;
    onSceneReady: (scene: Scene) => void;
    /**
     * Automatically trigger engine resize when the canvas resizes (default: true)
     */
    observeCanvasResize?: boolean;
    onRender?: (scene: Scene) => void;
    children?: React.ReactNode;
};
export declare type OnFrameRenderFn = (eventData: Scene, eventState: EventState) => void;
/**
 * Register a callback for before the scene renders.
 *
 * @param callback called using onBeforeRender functionality of scene
 * @param mask the mask used to filter observers
 * @param insertFirst if true will be inserted at first position, if false (default) will be last position.
 * @param callOnce only call the callback once
 */
export declare const useBeforeRender: (callback: OnFrameRenderFn, mask?: number | undefined, insertFirst?: boolean | undefined, callOnce?: boolean | undefined) => void;
/**
 * Register a callback for after the scene renders.
 *
 * @param callback called using onBeforeRender functionality of scene
 * @param mask the mask used to filter observers
 * @param insertFirst if true will be inserted at first position, if false (default) will be last position.
 * @param callOnce only call the callback once
 */
export declare const useAfterRender: (callback: OnFrameRenderFn, mask?: number | undefined, insertFirst?: boolean | undefined, callOnce?: boolean | undefined) => void;
/**
 * Handles creating a camera and attaching/disposing.
 * TODO: add new 4.2 parameters: useCtrlForPanning & panningMouseButton
 * @param createCameraFn function that creates and returns a camera
 * @param autoAttach Attach the input controls (default true)
 * @param noPreventDefault Events caught by controls should call prevent default
 * @param useCtrlForPanning (ArcRotateCamera only)
 * @param panningMoustButton (ArcRotateCamera only)
 */
export declare const useCamera: <T extends Camera>(createCameraFn: (scene: Scene) => T, autoAttach?: boolean, noPreventDefault?: boolean) => Nullable<T>;
declare const _default: (props: BabylonjsProps & React.CanvasHTMLAttributes<HTMLCanvasElement>) => JSX.Element;
export default _default;
